@@ -1,3 +1,6 @@
+# Copyright (C) 2021, QuantStack
+# SPDX-License-Identifier: BSD-3-Clause
+
 """
 Module that does most of the heavy lifting for the ``conda build`` command.
 """
@@ -579,7 +582,13 @@ def download_source(m, interactive=False):
         _try_download(m, interactive)
 
 
-def build(m, stats=None, from_interactive=False, allow_interactive=False):
+def build(
+    m,
+    stats=None,
+    from_interactive=False,
+    allow_interactive=False,
+    continue_on_failure=False,
+):
     try:
         if not stats:
             stats = {}
@@ -641,4 +650,4 @@ def build(m, stats=None, from_interactive=False, allow_interactive=False):
             asyncio.run(tui.enter_tui(m))
         else:
             console.print("[red]ERROR: Build failed!")
-            exit(1)
+            raise RuntimeError("Build failed")
